@@ -1,30 +1,29 @@
 /* EphemerisSearch.m
  * search Ephemeris data
  *
- * Copyright (C) 2004-2015 by Cenon GmbH
+ * Copyright (C) 2004-2006 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  2004-04-12
- * modified: 2014-11-20 (-setHeliocentricSearch: added)
- *           2014-01-04 (clean up)
+ * modified: 2006-02-04
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the Cenon Public License as
- * published by Cenon GmbH. Among other things, the
+ * modify it under the terms of the vhf Public License as
+ * published by vhf interservice GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the Cenon Public License for more details.
+ * See the vhf Public License for more details.
  *
- * You should have received a copy of the Cenon Public License along
- * with this program; see the file LICENSE. If not, write to Cenon.
+ * You should have received a copy of the vhf Public License along
+ * with this program; see the file LICENSE. If not, write to vhf.
  *
- * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
- * eMail: info@cenon.de
- * http://www.cenon.info
+ * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
+ * eMail: info@vhf.de
+ * http://www.vhf.de
  */
 
 #include <Foundation/Foundation.h>
@@ -51,7 +50,7 @@
  * seconds/degree = (24*3600) / degPerDay
  */
 static unsigned secsPerDegree[O_ARRAYSIZE] =		// average seconds per degree of arc
- {    87660,     6552,   21113,   53929,    164885,	// sun - mars
+ {    87660,     6552,   21120,   53929,    164885,	// sun - mars
     1032628,  2582188, 7365729, 9185626, 217632242,	// jupiter - pluto
    16286522, 16286522,  775757,  775757,		// node, apogee
     4296370, 0, 0, 0, 0, 0				// chiron
@@ -77,7 +76,6 @@ static unsigned secsPerDegree[O_ARRAYSIZE] =		// average seconds per degree of a
 {
     progressTarget = target;
     progressAction = action;
-    progressFr = 0.0; progressTo = 1.0;
 }
 
 - (void)setTopocentricSearch:(BOOL)topoFlag lat:(float)lat lon:(float)lon elev:(int)elev
@@ -90,14 +88,7 @@ static unsigned secsPerDegree[O_ARRAYSIZE] =		// average seconds per degree of a
         topoElev = elev;
     }
 }
-- (void)setHeliocentricSearch:(BOOL)helioFlag
-{
-    heliocentricSearch = helioFlag;
-}
-- (void)setEquatorialSearch:(BOOL)equatorFlag
-{
-    equatorialSearch = equatorFlag;
-}
+
 
 /* cycle length in minutes
  * created: 2006-01-10
@@ -166,17 +157,17 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
 
 /* return value of aspect
  * created:  2006-01-11 (from trader module)
- * modified: 2014-11-21
+ * modified: 2006-02-03
  */
 - (AstroAspectValue)valueOfAspect:(int)obj1 :(int)obj2 aspect:(SearchAspectType)asp
                            atDate:(NSCalendarDate*)date
 {   //static EphObject	ephBuffer[2];
-    double              v1, v2;
-    EphemerisFlags      ephFlags = EPHFLAG_LON;	// what to calculate
-    EphemerisObjects    ephObjIx[2];		// objects to calculate
-    int                 ephObjCnt = 0;		// number of objects in array
-    EphObject           *eph; //eph[O_ARRAYSIZE];
-    AstroAspectValue    value = {0.0, 0.0};
+    double		v1, v2;
+    EphemerisFlags	ephFlags = EPHFLAG_LON;	// what to calculate
+    EphemerisObjects	ephObjIx[2];		// objects to calculate
+    int			ephObjCnt = 0;		// number of objects in array
+    EphObject		*eph; //eph[O_ARRAYSIZE];
+    AstroAspectValue	value = {0.0, 0.0};
 
     if (obj1 != EPH_NONE)
         ephObjIx[ephObjCnt++] = obj1;
@@ -196,8 +187,8 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
 
         eph = [ephemeris objectsAtJD:[ephemeris julianDayForDate:date bc:NO] flags:ephFlags
                              objects:ephObjIx cnt:ephObjCnt
-                           longitude:topoLon latitude:topoLat elevation:topoElev topocentric:topocentricSearch
-                        heliocentric:heliocentricSearch equatorial:equatorialSearch];
+                           longitude:topoLon latitude:topoLat elevation:topoElev
+                         topocentric:topocentricSearch];
         //for (i=0; i<O_ARRAYSIZE; i++)
         //    eph[i] = ephObject[i];
     }
@@ -260,14 +251,6 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
     return value;
 }
 
-/* set range of progress indicator (default = full range = [0.0, 1.0])
- */
-- (void)setProgressFr:(double)fr to:(double)to
-{
-    progressFr = fr;
-    progressTo = to;
-}
-
 /* binary search for a single aspect
  *
  * results =
@@ -282,19 +265,19 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
 - (NSArray*)searchFromDate:(NSCalendarDate*)dateFr toDate:(NSCalendarDate*)dateTo
                    object1:(EphemerisObjects)obj1 object2:(EphemerisObjects)obj2
                     aspect:(SearchAspectType)aspType aspectValue:(double)aspVal
-{   NSMutableArray      *results = [NSMutableArray array];
-    //int               years = [dateTo yearOfCommonEra] - [dateFr yearOfCommonEra] + 1;
-    NSCalendarDate      *date;
-    int                 i, interval, minCycle, minRetro = 0, loop = 0, loopCnt = 0;
-    int                 secCnt = 0;
-    unsigned int        minDirect;
-    EphObject           *objects;
-    BOOL                retroAspect = NO, retro = NO;	// wheather aspect was retrograde in test sections
-    NSMutableArray      *sectionDates;
-    EphemerisFlags      ephFlags = 0;	// what to calculate
-    EphemerisObjects    ephObjIx[2];	// objects to calculate
-    int                 ephObjCnt = 0;	// number of objects in array
-    double              tjd;
+{   NSMutableArray	*results = [NSMutableArray array];
+    //int		years = [dateTo yearOfCommonEra] - [dateFr yearOfCommonEra] + 1;
+    NSCalendarDate	*date;
+    int			i, interval, minCycle, minRetro, loop = 0, loopCnt = 0;
+    int			secCnt = 0;
+    unsigned int	minDirect;
+    EphObject		*objects;
+    BOOL		retroAspect = NO, retro = NO;	// wheather aspect was retrograde in test sections
+    NSMutableArray	*sectionDates;
+    EphemerisFlags	ephFlags = 0;	// what to calculate
+    EphemerisObjects	ephObjIx[2];	// objects to calculate
+    int			ephObjCnt = 0;	// number of objects in array
+    double		tjd;
 
     if (obj1 != EPH_NONE)
         ephObjIx[ephObjCnt++] = obj1;
@@ -335,8 +318,7 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
     /*    we use smallest section (cycle, retro) to split from start to end of range */
     minCycle = [self minutesCycleForAspect:obj1 :obj2 aspect:aspType];
     minCycle -= minCycle / 10;	// 10% tolerance
-    if ( !heliocentricSearch )
-        minRetro = [self minutesRetroForAspect:obj1 :obj2 aspect:aspType direct:&minDirect];
+    minRetro = [self minutesRetroForAspect:obj1 :obj2 aspect:aspType direct:&minDirect];
     interval = (minRetro > 0) ? Min(minCycle, minRetro-minRetro/5) : minCycle;
     sectionDates = [NSMutableArray array];
     for ( date = dateFr;					// interval steps through range
@@ -351,10 +333,10 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
         tjd = [ephemeris julianDayForDate:date bc:NO];
         objects = [ephemeris objectsAtJD:tjd flags:ephFlags
                                  objects:ephObjIx cnt:ephObjCnt
-                               longitude:topoLon latitude:topoLat elevation:topoElev topocentric:topocentricSearch
-                            heliocentric:heliocentricSearch equatorial:equatorialSearch];
+                               longitude:topoLon latitude:topoLat elevation:topoElev
+                             topocentric:topocentricSearch];
         /* add section date only, if retro changes or delta >= 360deg */
-        if ( !secCnt || min >= minCycle-interval ||			// delta >= full cycle
+        if ( !secCnt || min >= minCycle ||			// delta >= full cycle
              retro != ((objects[obj1].vLon < 0.0) ? YES : NO) )	// retro changes
         {
             [sectionDates addObject:date];
@@ -388,11 +370,10 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
         loop = 0; loopCnt = secCnt*20*2;	// 1st 50% of progress bar
         [turnDates addObject:dateFr];
         for (i=0; i<secCnt-1; i++)	// for each section
-        {   NSCalendarDate      *secDateFr, *secDateTo;
-            int                 j;
-            AstroAspectValue    minV, v, maxV;
-            NSCalendarDate      *minDate, *maxDate, *date;
-            double              val;
+        {   NSCalendarDate	*secDateFr, *secDateTo;
+            int			j;
+            AstroAspectValue	minV, v, maxV;
+            NSCalendarDate	*minDate, *maxDate, *date;
 
             secDateFr = [sectionDates objectAtIndex:i];		// start date of section
             secDateTo = [sectionDates objectAtIndex:i+1];	// end   date of section
@@ -408,9 +389,8 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
                 date = [minDate addTimeInterval:secs/2];
                 v = [self valueOfAspect:obj1 :obj2 aspect:aspType atDate:date];
 
-                val = progressFr + ((double)loop/(double)loopCnt) * (progressTo-progressFr);
-                [progressTarget performSelector:progressAction withObject:[NSNumber numberWithDouble:val]];
-                loop++;
+                [progressTarget performSelector:progressAction
+                                     withObject:[NSNumber numberWithFloat:(float)loop++/(float)loopCnt]];
 
                 if (secs < 30 || v.v == 0.0)	// ready !
                     break;
@@ -451,15 +431,14 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
     loop    = (retroAspect) ? secCnt*20 : 0;
     loopCnt = secCnt*20 * ((retroAspect) ? 2 : 1);	// 2nd 50% of progress bar
     for (i=0; i<secCnt-1; i++)	// for each section
-    {   NSCalendarDate      *secDateFr, *secDateTo;
-        int                 j;
-        AstroAspectValue    minV, v, maxV;
-        NSCalendarDate      *minDate, *maxDate, *date;
-        BOOL                retro = NO;
-        double              val;
+    {   NSCalendarDate	*secDateFr, *secDateTo;
+        int			j;
+        AstroAspectValue	minV, v, maxV;
+        NSCalendarDate		*minDate, *maxDate, *date;
+        BOOL			retro = NO;
 
-        secDateFr = [sectionDates objectAtIndex:i];     // start date of section
-        secDateTo = [sectionDates objectAtIndex:i+1];   // end   date of section
+        secDateFr = [sectionDates objectAtIndex:i];	// start date of section
+        secDateTo = [sectionDates objectAtIndex:i+1];	// end   date of section
 
         /* actual binary search inside section */
         minDate = secDateFr;
@@ -481,9 +460,8 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
                     /*skip = YES,*/ break;
             }
 
-            val = progressFr + ((double)loop/(double)loopCnt) * (progressTo-progressFr);
-            [progressTarget performSelector:progressAction withObject:[NSNumber numberWithDouble:val]];
-            loop++;
+            [progressTarget performSelector:progressAction
+                                 withObject:[NSNumber numberWithFloat:(float)loop++/(float)loopCnt]];
 
             if (secs < 30)	// ready !
                 break;
@@ -511,7 +489,7 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
         }
     }
     [progressTarget performSelector:progressAction
-                         withObject:[NSNumber numberWithDouble:progressTo]];
+                         withObject:[NSNumber numberWithFloat:1.0]];
 
     [progressTarget performSelector:@selector(setTitle:) withObject:nil];
 
@@ -552,10 +530,10 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
  */
 #define SIGNSIZE	15	// [degrees]
 - (NSDictionary*)searchWithFeatures:(NSDictionary*)features
-                           fromDate:(NSDate*)dateFrom toDate:(NSDate*)dateTo
+                           fromDate:(NSCalendarDate*)dateFrom toDate:(NSCalendarDate*)dateTo
                      searchInterval:(int)minutes
 {   NSMutableDictionary	*dict = [NSMutableDictionary dictionary];
-    NSDate      *date = dateFrom, *date0;
+    NSCalendarDate	*date = dateFrom, *date0;
     NSArray		*planets = [features objectForKey:@"planets"];
     int			planetCnt = [planets count];
     int			p, p1, planetIx[planetCnt], i;
@@ -570,7 +548,7 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
     NSArray		*dividers = [features objectForKey:@"dividers"];
     int			divCnt = [dividers count];
     double		target[planetCnt][planetCnt][divCnt],
-                lastAngle [planetCnt][planetCnt][divCnt], closestAngle [planetCnt][planetCnt][divCnt];
+                        lastAngle [planetCnt][planetCnt][divCnt], closestAngle [planetCnt][planetCnt][divCnt];
     double		lastMirror[planetCnt][planetCnt][divCnt], closestMirror[planetCnt][planetCnt][divCnt];
 
     if (!(featureEnterSigns || featureAspects || featureMirrors) || ![planets count])	// nothing to do
@@ -586,7 +564,7 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
     /* create dictionaries for planets */
     for (p=0; p<planetCnt; p++)
     {   NSMutableDictionary	*planetDict = [NSMutableDictionary dictionary];
-        NSString            *planet = [planets objectAtIndex:p];
+        NSString		*planet = [planets objectAtIndex:p];
 
         [dict setObject:planetDict forKey:planet];
         planetIx[p] = [ephemeris indexForObjectName:planet];
@@ -598,10 +576,10 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
         }
         if (featureAspects || featureMirrors)
         {
-            if (p < planetCnt)
+            if (p < planetCnt-1)
                 [planetDict setObject:[NSMutableDictionary dictionary] forKey:@"aspects"];
             dividers = [dividers sortedArrayUsingSelector:@selector(compare:)];
-            for (p1=0; p1 < [planets count]; p1++)
+            for (p1=0; p1<[planets count]; p1++)
                 for (i=0; i<divCnt; i++)
                 {
                     target[p][p1][i] = 360.0 / [[dividers objectAtIndex:i] floatValue];
@@ -613,11 +591,7 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
 
     /* search through range */
     while ([date compare:dateTo] != NSOrderedDescending)	// date <= dateTo
-    {   //EphObject	*objects = [ephemeris objectsAtUTC:date];
-        EphObject	*objects = [ephemeris objectsAtUTC:date lat:topoLat lon:topoLon
-                                                elev:topoElev topocentric:topocentricSearch
-                                        heliocentric:heliocentricSearch
-                                          equatorial:equatorialSearch];
+    {   EphObject	*objects = [ephemeris objectsAtUTC:date];
 
         /* entry of sign */
         if (featureEnterSigns)
@@ -642,8 +616,7 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
                     delta  = Diff(vPrev, v);				// delta interval
                     delta1 = Diff(vPrev, targetSign*signSize);		// delta target
                     dSec = minutes*60 * delta1 / delta  - (minutes*60.0);
-                    date0 = [date dateByAddingTimeInterval:dSec];
-                    //date0 = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:0 seconds:dSec];
+                    date0 = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:0 seconds:dSec];
 
                     //printf("sign changed %s: signNo[%d]=%d sign=%d", [[date0 description] cString], p, signNo[p], sign);
                     entryDict = [[dict objectForKey:[planets objectAtIndex:p]] objectForKey:@"entrySign"];
@@ -658,11 +631,11 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
         /* aspects */
         if (featureAspects || featureMirrors)
         {
-            for ( p=0; p < ((planetCnt > 1) ? planetCnt-1 : 1); p++ )           // obj1
+            for (p=0; p<planetCnt-1; p++)
             {   double  deg = objects[planetIx[p]].lon;
 
-                for (p1 = p + ((planetCnt>1) ? 1 : 0); p1 < planetCnt; p1++)    // obj2: TODO: add positions
-                {   double  deg1 = (planetCnt > 1) ? objects[planetIx[p1]].lon : 0.0;
+                for (p1=p+1; p1<planetCnt; p1++)
+                {   double  deg1 = objects[planetIx[p1]].lon;
 
                     if (featureAspects)
                     {   double  a = angle(deg, deg1);
@@ -675,24 +648,23 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
                             if ( is <= lastAngle[p][p1][i] )
                                 closestAngle[p][p1][i] = is;
                             else if (closestAngle[p][p1][i] < 3.0)
-                            {   double              v, delta, delta1;
-                                int                 dSec;
-                                NSMutableDictionary *entryDict;
-                                NSArray             *entry;
+                            {   double			v, delta, delta1;
+                                int			dSec;
+                                NSMutableDictionary	*entryDict;
+                                NSArray			*entry;
 
                                 /* get exact date: date += deltaTime * delta1 / delta */
                                 v = (is < closestAngle[p][p1][i]) ? is+target[p][p1][i] : is;
                                 delta  = Diff(closestAngle[p][p1][i], target[p][p1][i]) + Diff(v, target[p][p1][i]);
                                 delta1 = Diff(closestAngle[p][p1][i], target[p][p1][i]);
                                 dSec = minutes*60 * delta1 / delta  - (minutes*60.0);
-                                date0 = [date dateByAddingTimeInterval:dSec];
-                                //date0 = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:dSec/60 seconds:0];
+                                date0 = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:dSec/60 seconds:0];
                                 //printf("%s %s  v=%f delta=%f delta1 = %f\n",
                                 //[[date descriptionWithCalendarFormat:@"%Y%m%d %H:%M:%S"] cString],
                                 //[[date0 descriptionWithCalendarFormat:@"%Y%m%d %H:%M:%S"] cString],
                                 //v, delta, delta1);
 
-                                v = floor((a+target[p][p1][i]/2.0) / target[p][p1][i]) * target[p][p1][i];
+                                v = floor((a+target[p][p1][i]/2.0)/target[p][p1][i]) * target[p][p1][i];
                                 if (v >= 360.0) v = 0.0;
                                 //printf("a=%f v=%f target[p][p1][i] = %f\n", a, v, target[p][p1][i]);
                                 entry = [NSArray arrayWithObjects:[planets objectAtIndex:p1],
@@ -717,10 +689,10 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
                                 closestMirror[p][p1][i] = is;
                             else if (closestMirror[p][p1][i] < 360.0
                                      && Diff(closestMirror[p][p1][i], target[p][p1][i]) < 3.0)
-                            {   double              v, delta, delta1;
-                                int                 dSec;
+                            {   double			v, delta, delta1;
+                                int			dSec;
                                 NSMutableDictionary	*entryDict;
-                                NSArray             *entry;
+                                NSArray			*entry;
 
                                 /* get exact date: date += deltaTime * delta1 / delta */
                                 v = (is < closestMirror[p][p1][i]) ? is+target[p][p1][i] : is;
@@ -728,8 +700,7 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
                                          Diff(v, target[p][p1][i]);
                                 delta1 = Diff(closestMirror[p][p1][i], target[p][p1][i]);
                                 dSec = minutes*60 * delta1 / delta  - (minutes*60.0);
-                                date0 = [date dateByAddingTimeInterval:dSec];
-                                //date0 = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:dSec/60 seconds:0];
+                                date0 = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:dSec/60 seconds:0];
 
                                 v = floor((m+target[p][p1][i]/2.0)/target[p][p1][i])*target[p][p1][i];
                                 if (v >= 360.0) v = 0.0;
@@ -746,8 +717,7 @@ static unsigned hoursDirect[O_ARRAYSIZE] =	// intervals between retrograde in ho
             }
         } // end aspects
 
-        date = [date dateByAddingTimeInterval:minutes*60];
-        //date = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:minutes seconds:0];
+        date = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:minutes seconds:0];
     }
 
 NSLog(@"Search dict = %@", dict);
@@ -757,8 +727,7 @@ NSLog(@"Search dict = %@", dict);
 
 /* search aspects
  * created:  2004-05-20
- * modified: 2009-02-22 (find flip via flipping modulo(angle) from both sides, don't include approaches)
- *           2006-05-23 (progress bar added)
+ * modified: 2006-05-23 (progress bar added)
  *
  * return
  * {
@@ -771,18 +740,17 @@ NSLog(@"Search dict = %@", dict);
                  searchAngles:(BOOL)searchAngles searchMirrors:(BOOL)searchMirrors
                      fromDate:(NSCalendarDate*)dateFrom toDate:(NSCalendarDate*)dateTo
                searchInterval:(int)minutes
-{   NSMutableDictionary *dict = [NSMutableDictionary dictionary];
-    NSCalendarDate      *date = dateFrom, *date0;
-    int                 p1 = [ephemeris indexForObjectName:planet1];
-    int                 p2 = [ephemeris indexForObjectName:planet2];
-    int                 i, divCnt = [dividers count], loop, loopCnt;
-    double              target[divCnt], lastAngle[divCnt], closestAngle[divCnt];
-    double              lastMirror[divCnt], closestMirror[divCnt];
-    //double            jd, jdTo, jdInterval = minutes / (24.0*60.0);
-    NSArray             *entry;
-    EphemerisFlags      ephFlags = EPHFLAG_LON; // what to calculate
-    EphemerisObjects    ephObjIx[2];            // objects to calculate
-    int                 ephObjCnt = 0;          // number of objects in array
+{   NSMutableDictionary	*dict = [NSMutableDictionary dictionary];
+    NSCalendarDate	*date = dateFrom, *date0;
+    int			p1 = [ephemeris indexForObjectName:planet1];
+    int			p2 = [ephemeris indexForObjectName:planet2];
+    int			i, divCnt = [dividers count], loop, loopCnt;
+    double		target[divCnt], lastAngle[divCnt], closestAngle[divCnt];
+    double		lastMirror[divCnt], closestMirror[divCnt];
+    NSArray		*entry;
+    EphemerisFlags	ephFlags = EPHFLAG_LON;	// what to calculate
+    EphemerisObjects	ephObjIx[2];		// objects to calculate
+    int			ephObjCnt = 0;		// number of objects in array
 
     if (!searchAngles && !searchMirrors)
         return dict;
@@ -800,53 +768,39 @@ NSLog(@"Search dict = %@", dict);
 
     loop = 0;
     loopCnt = ([dateTo timeIntervalSinceDate:date]/60.0) / minutes;
-    //jd   = [ephemeris julianDayForDate:date   bc:NO];
-    //jdTo = [ephemeris julianDayForDate:dateTo bc:NO];
-    //while ( jd <= jdTo )    // date <= dateTo
     while ([date compare:dateTo] != NSOrderedDescending)	// date <= dateTo
-    {   NSAutoreleasePool   *pool = [NSAutoreleasePool new];
-        EphObject           *objects;	// = [ephemeris objectsAtUTC:date];
+    {   NSAutoreleasePool	*pool = [NSAutoreleasePool new];
+        EphObject		*objects;	// = [ephemeris objectsAtUTC:date];
 
-        objects = [ephemeris objectsAtJD:/*jd*/[ephemeris julianDayForDate:date bc:NO] flags:ephFlags
+        objects = [ephemeris objectsAtJD:[ephemeris julianDayForDate:date bc:NO] flags:ephFlags
                                  objects:ephObjIx cnt:ephObjCnt
-                               longitude:topoLon latitude:topoLat elevation:topoElev topocentric:topocentricSearch
-                            heliocentric:heliocentricSearch equatorial:equatorialSearch];
+                               longitude:topoLon latitude:topoLat elevation:topoElev
+                             topocentric:topocentricSearch];
 
         [date retain];
         if (searchAngles)
         {   double	a = angle(objects[p1].lon, objects[p2].lon);
 
             for (i=divCnt-1; i>=0; i--)	// use the biggest divider, if more than one divider fit
-            {   double	is = a - floor(a / target[i]) * target[i];      // modulo denom
-                double  isDelta = Min(is, target[i] - is);              // delta from target
-                double  lsDelta = Min(lastAngle[i], target[i] - is);    // delta from target
+            {   double	is = a - floor(a / target[i]) * target[i];
 
-                //printf("%s: last=%f is=%f d=%f closest=%f t=%f\n", [[date  descriptionWithCalendarFormat:@"%Y%m%d %H:%M:%S"] cString], lastAngle[i], is, isDelta, closestAngle[i], target[i]);
-
-                if ( Diff(lastAngle[i], is) < target[i]/2.0 &&  // no flip
-                     isDelta <= lsDelta )                       // delta getting smaller
-                     //Diff(is, target[i]) <= Diff(lastAngle[i], target[i]) )	// delta getting smaller (one direction only!)
+                if ( Diff(is, target[i]) <= Diff(lastAngle[i], target[i]) )	// delta getting smaller
                     closestAngle[i] = is;
-                else if ( closestAngle[i] < 500.0 && (Diff(lastAngle[i], is) > target[i]/2.0    // flip
-                          /*|| Diff(closestAngle[i], target[i]) < 1.0*/) )                      // approach
+                else if (closestAngle[i] < 500.0 && Diff(closestAngle[i], target[i]) < 1.0)	// flip
                 {   double	isSign = ((is           > target[i]/2.0) ? -(target[i]-is) : is);
-                    double	prSign = ((lastAngle[i] > target[i]/2.0) ? -(target[i]-lastAngle[i]) : lastAngle[i]);
+                    double	prSign = ((lastAngle[i] > target[i]/2.0) ? -(target[i]-lastAngle[i])
+                                                                         : lastAngle[i]);
                     //int	dir = (isSign > prSign) ? 1 : -1;
                     double	v, delta, delta1;
                     int		dSec;
 
                     /* get exact date: date += deltaTime * delta1 / delta */
-                    if (isSign < prSign + 0.00001)   // retrograde -> we are one step to far (no, fixed)
+                    if (isSign < prSign)	// retrograde -> we are one step to far
                     {
-                        delta  = Diff(isSign, prSign);  // delta of time interval
-                        delta1 = Abs(prSign);           // delta to target
-                        dSec = - ((minutes*60) - (minutes*60 * delta1 / delta));
-                        if (Abs(dSec/60) > minutes)
-                        {   NSLog(@"searchAspect, error in calculation: dSec = %d", dSec);
-                            dSec = 0.0;
-                        }
-                        //date0 = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:dSec/60 seconds:0];
-                        date0 = [date dateByAddingTimeInterval:dSec];
+                        delta  = Diff(isSign, prSign);	// delta of time interval
+                        delta1 = Abs(prSign);		// delta to target
+                        dSec = - (minutes*60 * delta1 / delta) - (minutes*60);
+                        date0 = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:dSec/60 seconds:0];
                     }
                     else	// FIXME: this should work with the signed angles as well
                     {
@@ -854,14 +808,13 @@ NSLog(@"Search dict = %@", dict);
                         delta  = Diff(closestAngle[i], target[i]) + Diff(v, target[i]);
                         delta1 = Diff(closestAngle[i], target[i]);
                         dSec = minutes*60 * delta1 / delta - (minutes*60.0);
-                        //date0 = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:dSec/60 seconds:0];
-                        date0 = [date dateByAddingTimeInterval:dSec];
+                        date0 = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:dSec/60 seconds:0];
                     }
 
-                    /*printf("last=%f (%f) is=%f (%f) closest=%f t+is=%f t=%f\n", lastAngle[i], lsDelta, is, isDelta, closestAngle[i], is+target[i], target[i]);
-                    printf("date='%s' date0='%s'  v=%f delta=%f delta1=%f\n",
-                        [[date  descriptionWithCalendarFormat:@"%Y%m%d %H:%M:%S"] cString],
-                        [[date0 descriptionWithCalendarFormat:@"%Y%m%d %H:%M:%S"] cString], v, delta, delta1);*/
+//printf("last=%f is=%f closest=%f t+is=%f t=%f\n", lastAngle[i], is, closestAngle[i], is+target[i], target[i]);
+//printf("date='%s' date0='%s'  v=%f delta=%f delta1=%f\n",
+//       [[date  descriptionWithCalendarFormat:@"%Y%m%d %H:%M:%S"] cString],
+//       [[date0 descriptionWithCalendarFormat:@"%Y%m%d %H:%M:%S"] cString], v, delta, delta1);
 
                     v = floor((a+target[i]/2.0)/target[i])*target[i];	// target angle
                     entry = [NSArray arrayWithObjects:planet1, planet2,
@@ -889,18 +842,17 @@ NSLog(@"Search dict = %@", dict);
                 else if (closestMirror[i] < 500.0 && Diff(closestMirror[i], target[i]) < 1.0)
                 {   double	isSig = ((is            > target[i]/2.0) ? -(target[i]-is) : is);
                     double	prSig = ((lastMirror[i] > target[i]/2.0) ? -(target[i]-lastMirror[i])
-                                                                     : lastMirror[i]);
+                                                                         : lastMirror[i]);
                     double	v, delta, delta1;
                     int		dSec;
 
                     /* get exact date: date += deltaTime * delta1 / delta */
-                    if (isSig < prSig + 0.00001)    // retrograde -> we are one step to far
+                    if (isSig < prSig)	// retrograde -> we are one step to far
                     {
                         delta  = Diff(isSig, prSig);	// delta of time interval
                         delta1 = Abs(prSig);		// delta to target
                         dSec = - (minutes*60 * delta1 / delta) - (minutes*60);
-                        //date0 = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:dSec/60 seconds:0];
-                        date0 = [date dateByAddingTimeInterval:dSec];
+                        date0 = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:dSec/60 seconds:0];
                     }
                     else	// FIXME: this should work with the signed angles as well
                     {
@@ -908,8 +860,7 @@ NSLog(@"Search dict = %@", dict);
                         delta  = Diff(closestMirror[i], target[i]) + Diff(v, target[i]);
                         delta1 = Diff(closestMirror[i], target[i]);
                         dSec = minutes*60 * delta1 / delta  - (minutes*60.0);
-                        //date0 = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:dSec/60 seconds:0];
-                        date0 = [date dateByAddingTimeInterval:dSec];
+                        date0 = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:dSec/60 seconds:0];
                     }
                     v = floor((m+target[i]/2.0)/target[i])*target[i];	// target mirror angle
                     entry = [NSArray arrayWithObjects:planet1, planet2,
@@ -925,15 +876,11 @@ NSLog(@"Search dict = %@", dict);
             }
         }
 
-        if ( loopCnt < 1000 || (loopCnt < 10000 && loop%10 == 0) || loop%100 == 0 )
-            [progressTarget performSelector:progressAction
-                                 withObject:[NSNumber numberWithFloat:(float)loop/(float)loopCnt]];
-        loop++;
+        [progressTarget performSelector:progressAction
+                             withObject:[NSNumber numberWithFloat:(float)loop++/(float)loopCnt]];
 
         [date autorelease];
-        //date = [[date dateByAddingYears:0 months:0 days:0 hours:0 minutes:minutes seconds:0] retain];
-        date = [[date dateByAddingTimeInterval:minutes*60.0] retain];
-        //jd += jdInterval;
+        date = [[date dateByAddingYears:0 months:0 days:0 hours:0 minutes:minutes seconds:0] retain];
         [pool release];
     }
 
