@@ -1,11 +1,11 @@
 /* Ephemeris.h
  * front end object for the Swiss Ephemeris
  *
- * Copyright (C) 1999-2005 by Georg Fleischmann
+ * Copyright (C) 1999-2006 by Georg Fleischmann
  * Author:   Georg Fleischmann
  *
  * created:  1999-11-30
- * modified: 2005-10-19
+ * modified: 2006-08-18
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -31,7 +31,7 @@
 
 #include	"swephexp.h"
 
-/* planet names and intersections for earth projection in order of objects array
+/* planet names and intersections in order of objects array
  * (see swephexp.h: SE_XXX)
  */
 #define OBJECTS	[NSArray arrayWithObjects:@"Sun", @"Moon", @"Mercury", @"Venus", @"Mars", @"Jupiter", @"Saturn", @"Uranus", @"Neptune", @"Pluto", @"Node", @"True Node", @"Apogee", @"True Apogee", @"Earth", @"Chiron", @"Pholus", @"Ceres", @"Pallas", @"Juno", @"Vesta", nil]
@@ -62,10 +62,14 @@ typedef enum
     PALLAS     = SE_PALLAS,
     JUNO       = SE_JUNO,
     VESTA      = SE_VESTA,
-    AC         = 21,
-    MC         = 22
-}EphemerisObjects;
+    AC         = 21,	// deprecated
+    EPH_AC     = 21,
+    MC         = 22,	// deprecated
+    EPH_MC     = 22,
+    EPH_NONE   = -1	// no object
+} EphemerisObjects;
 
+/* deprecated */
 #define O_SUN		SE_SUN
 #define O_MOON		SE_MOON
 #define O_MERCURY	SE_MERCURY
@@ -91,6 +95,19 @@ typedef enum
 
 #define O_ARRAYSIZE	23	// enough room to store all objects
 
+/* flags */
+typedef enum
+{
+    EPHFLAG_LON =   1,	// ecliptiocal longitude (+ latitude)
+    EPHFLAG_LAT =   2,	// ecliptical latitude
+    EPHFLAG_DEC =   4,	// declination (+ rectaascension)
+    EPHFLAG_REC	=   8,	// rect ascension
+    EPHFLAG_NOD	=  16,	// Nodes Lon + Lat (+ Perihelion + Aphelion)
+    EPHFLAG_HEL	=  32,	// Perihelion / Aphelion
+    //EPHFALG_EQU =  64,	// Equatorial: Node declination, Perigee, Apogee
+    EPHFLAG_LOC = 128	// AC / MC
+} EphemerisFlags;
+
 /* structure holding the data of each planet
  */
 typedef struct
@@ -98,7 +115,7 @@ typedef struct
     double	lon;		// the zodiac position (ecliptical longitude)
     double	lat;		// Ecliptic latitude
     double	vLon;		// speed in longitude (deg/day), negative = retrograde
-    double	vLat;		// speed in latitude (deg/day), negative = retrograde
+    double	vLat;		// speed in latitude  (deg/day), negative = retrograde
 
     double	rec;		// equatorial rectascension
     double	dec;		// equatorial declination (earth latitude)
@@ -106,20 +123,20 @@ typedef struct
     double	vDec;		// speed in declination
 
     double	nodeLon;	// ecliptical longitude of ascending node
-    double	nodeLat;	// ecliptical latitude of ascending node
+    double	nodeLat;	// ecliptical latitude  of ascending node
     double	nodeVLon;	// speed of ascending node in longitude
     double	nodeVLat;	// speed of ascending node in latitude
     double	dscNodeLon;	// ecliptical longitude of descending node
-    double	dscNodeLat;	// ecliptical latitude of descending node
+    double	dscNodeLat;	// ecliptical latitude  of descending node
     double	dscNodeVLon;	// speed of descending node in longitude
     double	dscNodeVLat;	// speed of descending node in latitude
 
     double	perihelionLon;	// ecliptical longitude of perihelion (closest to Sun)
-    double	perihelionLat;	// ecliptical latitude of perihelion
+    double	perihelionLat;	// ecliptical latitude  of perihelion
     double	perihelionVLon;	// speed of perihelion in longitude
     double	perihelionVLat;	// speed of perihelion in latitude
     double	aphelionLon;	// ecliptical longitude of aphelion (farthest to Sun)
-    double	aphelionLat;	// ecliptical latitude of aphelion
+    double	aphelionLat;	// ecliptical latitude  of aphelion
     double	aphelionVLon;	// speed of aphelion in longitude
     double	aphelionVLat;	// speed of aphelion in latitude
 
@@ -138,6 +155,10 @@ typedef struct
     NSArray	*objectNames;
     EphObject	objects[30];
     BOOL	calculateMeanNodes;
+
+    double	calcJD;		// last calculation date
+    BOOL	calcTopo;
+    float	calcLat, calcLon, calcElev;
 }
 
 - (id)init;
@@ -147,14 +168,31 @@ typedef struct
 
 - (int)indexForObjectName:(NSString*)name;
 
+/* date -> julian day (reference = -4712) */
+- (double)julianDayForDate:(NSCalendarDate*)utc bc:(BOOL)bcFlag;
+- (double)julianDayForYear:(int)year month:(int)month day:(int)day
+                      hour:(int)hour minute:(int)minute second:(int)second bc:(BOOL)bcFlag;
+
+/* NSCalendar date methods */
 - (EphObject*)objectsAtUTC:(NSCalendarDate*)utc;
-- (EphObject*)objectsAtUTC:(NSCalendarDate*)utc lat:(float)lat lon:(float)lon;
+- (EphObject*)objectsAtUTC:(NSCalendarDate*)utc lat:(float)lat  lon:(float)lon;
 - (EphObject*)objectsAtUTC:(NSCalendarDate*)utc lat:(double)lat lon:(double)lon
                       elev:(double)alt topocentric:(BOOL)topocentric;
+- (BOOL)calculatedAtDate:(NSCalendarDate*)date tolerance:(int)tol
+                     lat:(float)lat lon:(float)lon elev:(float)elev topocentric:(BOOL)topo;
+/* year, month, day, ... methods */
 - (EphObject*)objectsAtYear:(int)year month:(int)month day:(int)day
                        hour:(int)hour minute:(int)minute second:(int)second
                   longitude:(double)lon latitude:(double)lat elevation:(double)alt;
+/* basic method using julian day (universal time, reference = -4712)
+ * also uses external flag: calculateMeanNodes
+ */
+- (EphObject*)objectsAtJD:(double)tjd flags:(EphemerisFlags)ephFlags
+                  objects:(EphemerisObjects*)objs cnt:(int)objCnt
+                longitude:(double)lon latitude:(double)lat elevation:(double)alt
+              topocentric:(BOOL)topoFlag;
 
+/* dictionary frontend methods */
 - (NSMutableDictionary*)objectDictAtUTC:(NSCalendarDate*)utc;
 - (NSMutableDictionary*)objectDictAtUTC:(NSCalendarDate*)utc lat:(float)lat lon:(float)lon;
 - (NSMutableDictionary*)objectDictAtUTC:(NSCalendarDate*)utc lat:(double)lat lon:(double)lon
@@ -165,6 +203,7 @@ typedef struct
 - (NSMutableDictionary*)currentDeclinationDict;	// dec
 - (NSMutableDictionary*)currentSpeedDecDict;	// V dec
 
+/* houses */
 - (double*)houseAtUTC:(NSCalendarDate*)utc latitude:(float)lat longitude:(float)lon houseCount:(int)houseCnt;
 
 @end
