@@ -1,41 +1,35 @@
 /* astroCommon.h
  * Common astronomical functions
  *
- * Copyright (C) 1998-2015 by Cenon GmbH
+ * Copyright (C) 1998-2006 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1998-11-06
- * modified: 2015-12-19 (cenNSDateFromJD() added)
- *           2015-05-14 (cenJD() added)
- *           2014-12-13 (asc. invariable node)
- *           2011-03-21 (vhfJDFromNSDate)
+ * modified: 2006-07-21
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the Cenon Public License as
- * published by Cenon GmbH. Among other things, the
+ * modify it under the terms of the vhf Public License as
+ * published by vhf interservice GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the Cenon Public License for more details.
+ * See the vhf Public License for more details.
  *
- * You should have received a copy of the Cenon Public License along
- * with this program; see the file LICENSE. If not, write to Cenon.
+ * You should have received a copy of the vhf Public License along
+ * with this program; see the file LICENSE. If not, write to vhf.
  *
- * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
- * eMail: info@cenon.de
- * http://www.cenon.info
+ * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
+ * eMail: info@vhf.de
+ * http://www.vhf.de
  */
 
-#ifndef CEN_H_ASTROCOMMON
-#define CEN_H_ASTROCOMMON
+#ifndef VHF_H_ASTROCOMMON
+#define VHF_H_ASTROCOMMON
 
-#include <VHFShared/vhfCompatibility.h>     // CGFloat for OS X 10.4
-
-double sunNode(int year);           // sun equator + ecliptic
-double invariableNode(int year);    // ascending invariable node
+float sunNode(int year);
 
 NSMutableData* reducedTable(NSData *tableData, int tableSize, double factor);
 NSMutableData* normalizedTable(NSData *table, int tableSize, BOOL positive);
@@ -55,7 +49,7 @@ double harmonicValue(double deg);
 NSString *stringFromDeg(float deg);
 float degFromString(NSString *degString);
 
-NSInteger sortAsNumbers(id str1, id str2, void *context);
+int sortAsNumbers(id str1, id str2, void *context);
 
 float frac(float x);
 
@@ -64,18 +58,9 @@ double vhfMJD(NSCalendarDate *date);
 double vhfSideralTimeMJD(double mjd, float lon);
 
 /* Julian Day (reference = -4712, compatible to swiss ephemeris) */
-double cenJD(int year, int month, int day, int H, int M, int S);
-double cenJDFromNSDate(NSDate *date);
-/* DEPRECATED */ double vhfJDFromNSDate(NSDate *date);
 double vhfJulianDay(NSCalendarDate *date);
 double vhfJulianDayFromInt(int yyyymmdd, int hhmm);
-//double vhfJulianDayFromNSDate(NSCalendarDate *date);
-int cenIntDateFromJD(double jd, int *yymmdd, int *hhmm);
-int cenIntDateFromJulianDay(double jd, int *yymmdd, int *hhmm);
-/* DEPRECATED */ int vhfIntDateFromJulianDay(double jd, int *yymmdd, int *hhmm);
-NSDate *cenNSDateFromJD(double jd);
-//NSDate *cenNSDateFromJulianDay(double jd);
-/* DEPRECATED */ NSCalendarDate *vhfNSDateFromJD(double jd);
+int vhfIntDateFromJulianDay(double jd, int *yymmdd, int *hhmm);
 double vhfSideralTime(double jd, float lon);	// sideral time in hours
 
 /* calculate astronomical values with sideral time [hours] (or better seconds and integer ???) */
@@ -88,7 +73,7 @@ float vhfLonForSideralTime(double st, NSCalendarDate *gmt);
 float vhfLonForMC(float mcDeg, NSCalendarDate *utc);
 float vhfLatForAC(float acDeg, double st);
 
-/* calculate astronomical values using NSCalendarDate (DEPRECATED ! too slow and no BC) */
+/* calculate astronomical values using NSCalendarDate (DEPRECATED !) */
 NSCalendarDate *sideralTime(NSCalendarDate *gmt, float longitude);
 float mc(NSCalendarDate *sideralTime);
 float ac(NSCalendarDate *sideralTime, float latitude);
@@ -104,9 +89,8 @@ NSString *nodeSymbol(NSString *planet);
 NSString *zodiacSign(int sign);
 NSString *aspectSymbol(float deg, float orb);
 
-/* modulo */
-//double modulo(double num, double denom);    // dodulo
-double mod360(double deg);                  // modulo 360 degree
+/* modulus */
+double mod360(double deg);			// modulus 360 degree
 
 /* aspects */
 double standardAngle( double angle );		// modulus 360 degree
@@ -120,4 +104,4 @@ double harmony(double obj, double obj1, double obj2);
 BOOL vhfIsDegreeInsideRange(double deg, double degFr, double degTo, BOOL retro);
 
 
-#endif // CEN_H_ASTROCOMMON
+#endif // VHF_H_ASTROCOMMON
