@@ -1,36 +1,36 @@
 /* astroMessages.h
  * common bundle messages
  *
- * Copyright (C) 2003-2010 by Cenon GmbH
+ * Copyright (C) 2003-2006 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  2003-06-22
  * modified: 2006-05-10
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the Cenon Public License as
- * published by Cenon GmbH. Among other things, the
+ * modify it under the terms of the vhf Public License as
+ * published by vhf interservice GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the Cenon Public License for more details.
+ * See the vhf Public License for more details.
  *
- * You should have received a copy of the Cenon Public License along
- * with this program; see the file LICENSE. If not, write to Cenon.
+ * You should have received a copy of the vhf Public License along
+ * with this program; see the file LICENSE. If not, write to vhf.
  *
- * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
- * eMail: info@cenon.de
- * http://www.cenon.info
+ * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
+ * eMail: info@vhf.de
+ * http://www.vhf.de
  */
 
-#ifndef CEN_H_ASTROMESSAGES
-#define CEN_H_ASTROMESSAGES
+#ifndef VHF_H_ASTROMESSAGES
+#define VHF_H_ASTROMESSAGES
 
-#define ASTRO_BUNDLE                [NSBundle bundleForClass:[AstroPrincipal class]]
-#define VHFLocalAstroString(key)    NSLocalizedStringFromTableInBundle(key, @"Astro", ASTRO_BUNDLE, NULL)
+#define ASTRO_BUNDLE			[NSBundle bundleForClass:[AstroPrincipal class]]
+#define VHFLocalAstroString(key)	NSLocalizedStringFromTableInBundle(key, @"Astro", ASTRO_BUNDLE, NULL)
 
 /* Preferences */
 #define PREF_GENERAL_TITLE		VHFLocalAstroString(@"General")
@@ -55,4 +55,4 @@
 /* City Manager */
 #define REALLYDELETECITY_STRING		VHFLocalAstroString(@"Do you really want to remove the city '%@' ?")
 
-#endif // CEN_H_ASTROMESSAGES
+#endif // VHF_H_ASTROMESSAGES
